from typing import Dict

from .. import Provider as LoremProvider


class Provider(LoremProvider):
    """Implement lorem provider for ``fa_IR`` locale.

    Word list is based on the source(s) below, and some words have been removed
    to make the word list appropriate for public testing.

    Sources:

    - https://1000mostcommonwords.com/1000-most-common-persian-words/
    """

    word_list = (
        "عنوان",
        "من",
        "خود",
        "که",
        "او",
        "بود",
        "برای",
        "در",
        "با",
        "آن‌ها",
        "بودن",
        "در",
        "یک",
        "دارند",
        "این",
        "از",
        "توسط",
        "داغ",
        "کلمه",
        "اما",
        "چه",
        "برخی",
        "است",
        "آن",
        "شما",
        "یا",
        "حال",
        "تر",
        "از",
        "به",
        "و",
        "دست",
        "در",
        "ما",
        "می‌توانید",
        "از",
        "دیگر",
        "بود",
        "که",
        "انجام",
        "شان",
        "زمان",
        "اگر",
        "خواهد‌شد",
        "چگونه",
        "گفت:",
        "پا",
        "هر",
        "بگو",
        "می‌کند",
        "مجموعه",
        "سه",
        "می‌خواهم",
        "هوا",
        "خوبی",
        "همچنین",
        "بازی",
        "کوچک",
        "پایان",
        "قراردادن",
        "خانه",
        "به‌عنوان",
        "دست",
        "بندر",
        "بزرگ",
        "طلسم",
        "اضافه",
        "حتی",
        "زمین",
        "اینجا",
        "باید",
        "بزرگ",
        "بالا",
        "ازجمله",
        "دنبال",
        "عمل",
        "بپرسید",
        "مردها",
        "تغییر",
        "رفت",
        "نور",
        "نوع",
        "خاموش",
        "نیاز",
        "خانه",
        "تصویر",
        "سعی‌کنید",
        "ما",
        "دوباره",
        "حیوانات",
        "نقطه",
        "مادر",
        "جهان",
        "در‌نزدیکی",
        "ساخت",
        "خود",
        "زمین",
        "پدر",
        "هر",
        "جدید",
        "کار",
        "بخش",
        "را",
        "دریافت",
        "محل",
        "ساخته",
        "زنده",
        "کمی",
        "تنها",
        "دور",
        "مرد",
        "سال",
        "آمد",
        "نمایش",
        "هر",
        "خوب",
        "را",
        "ما",
        "در",
        "بسیار",
        "فقط",
        "فرم",
        "حکم",
        "بزرگ",
        "می‌گویند",
        "کمک",
        "کم",
        "خط",
        "متفاوت",
        "علت",
        "بسیار",
        "متوسط",
        "قبل",
        "حرکت",
        "راست",
        "پسر",
        "قدیمی",
        "هم",
        "همان",
        "او",
        "همه",
        "وجوددارد",
        "بالا",
        "استفاده",
        "راه",
        "درمورد",
        "نوشتن",
        "را",
        "مانند",
        "تا",
        "این‌ها",
        "او",
        "طولانی",
        "را",
        "ببینید",
        "او",
        "دو",
        "دارد",
        "نگاه",
        "تر",
        "روز",
        "می‌تواند",
        "به",
        "آمده",
        "انجام",
        "تعداد",
        "صدا",
        "هیچ",
        "بیشترین",
        "مردم",
        "من",
        "روی",
        "می‌دانم",
        "اب",
        "تماس",
        "اولین",
        "که",
        "پایین",
        "سمت",
        "بوده",
        "ساعت",
        "سر",
        "ایستادن",
        "خود",
        "صفحه",
        "باید",
        "کشور",
        "یافت",
        "پاسخ",
        "مدرسه",
        "رشد",
        "مطالعه",
        "هنوز",
        "یادگیری",
        "کارخانه",
        "پوشش",
        "آفتاب",
        "چهار",
        "بین",
        "دولت",
        "چشم",
        "هرگز",
        "آخرین",
        "اجازه",
        "فکر",
        "شهرستان",
        "درخت",
        "صلیب",
        "مزرعه",
        "سخت",
        "شروع",
        "زور",
        "داستان",
        "اره",
        "بسیار",
        "دریا",
        "اواخر",
        "اجرا",
        "نکن",
        "مطبوعات",
        "نزدیک",
        "شب",
        "واقعی",
        "زندگی",
        "کم",
        "شمال",
        "کتاب",
        "حمل",
        "علم",
        "خوردن",
        "اتاق",
        "دوستان",
        "ایده",
        "ماهی",
        "کوه",
        "توقف",
        "پایه",
        "گوش",
        "اسب",
        "برش",
        "مطمئن",
        "تماشای",
        "رنگ",
        "صورت",
        "چوب",
        "اصلی",
        "باز",
        "باهم",
        "بعدی",
        "سفید",
        "کودکان",
        "شروع",
        "رو",
        "مثال",
        "آسان",
        "مقاله",
        "گروه",
        "همیشه",
        "موسیقی",
        "آن",
        "هردو",
        "علامت",
        "غالبا",
        "نامه",
        "مایل",
        "رودخانه",
        "اتومبیل",
        "پا",
        "مراقبت",
        "دوم",
        "کافی",
        "ساده",
        "دختر",
        "معمول",
        "جوان",
        "اماده",
        "بالا",
        "همیشه",
        "قرمز",
        "لیست",
        "هرچند",
        "احساس",
        "بحث",
        "پرنده",
        "بزودی",
        "بدن",
        "سگ",
        "خانواده",
        "مستقیم",
        "مطرح",
        "ترک",
        "آهنگ",
        "درب",
        "محصول",
        "کوتاه",
        "کلاس",
        "باد",
        "سوال",
        "کامل",
        "کشتی",
        "منطقه",
        "نیم",
        "سنگ",
        "منظور",
        "آتش",
        "جنوب",
        "مشکل",
        "قطعه",
        "گفت",
        "عبور",
        "بالا",
        "تمام",
        "پادشاه",
        "خیابان",
        "اینچ",
        "ضرب",
        "هیچ",
        "البته",
        "اقامت",
        "چرخ",
        "کامل",
        "نیروی",
        "آبی",
        "شی",
        "سطح",
        "عمیق",
        "ماه",
        "جزیره",
        "پا",
        "سیستم",
        "مشغول",
        "آزمون",
        "رکورد",
        "قایق",
        "مشترک",
        "طلا",
        "ممکن",
        "هواپیما",
        "جا",
        "خشک",
        "خنده",
        "هزار",
        "پیش",
        "فرار",
        "بررسی",
        "بازی",
        "شکل",
        "برابر",
        "داغ",
        "دست",
        "آورده",
        "حرارت",
        "برف",
        "لاستیک",
        "را",
        "بله",
        "دور",
        "پر",
        "شرق",
        "رنگ",
        "زبان",
        "درمیان",
        "واحد",
        "قدرت",
        "شهر",
        "خوب",
        "معین",
        "پرواز",
        "سقوط",
        "شود",
        "فریاد",
        "تاریک",
        "ماشین",
        "یادداشت",
        "صبر",
        "برنامه",
        "شکل",
        "ستاره",
        "جعبه",
        "اسم",
        "حوزه",
        "بقیه",
        "درست",
        "قادر",
        "پوند",
        "انجام",
        "زیبایی",
        "درایو",
        "شامل",
        "جلو",
        "آموزش",
        "هفته",
        "نهایی",
        "به",
        "سبز",
        "آه",
        "سریع",
        "توسعه",
        "اقیانوس",
        "گرم",
        "رایگان",
        "دقیقه",
        "قوی",
        "ویژه",
        "ذهن",
        "روشن",
        "دم",
        "محصول",
        "واقع",
        "فضا",
        "شنیده",
        "بهترین",
        "ساعت",
        "بهتر",
        "در",
        "صد",
        "پنج",
        "گام",
        "اوایل",
        "غرب",
        "زمین",
        "علاقه",
        "سریع",
        "فعل",
        "شش",
        "جدول",
        "سفر",
        "کمتر",
        "صبح",
        "ده",
        "ساده",
        "چند",
        "واکه",
        "جنگ",
        "دربرابر",
        "الگوی",
        "کند",
        "مرکز",
        "فرد",
        "پول",
        "خدمت",
        "جاده",
        "نقشه",
        "باران",
        "قانون",
        "حکومت",
        "کشیدن",
        "سرد",
        "اطلاع",
        "صدای",
        "انرژی",
        "شکار",
        "احتمالی",
        "تخت",
        "برادر",
        "سوار",
        "سلول",
        "باور",
        "شاید",
        "ناگهانی",
        "شمار",
        "مربع",
        "دلیل",
        "طول",
        "نمایندگی",
        "هنر",
        "موضوع",
        "منطقه",
        "اندازه",
        "کنند",
        "وزن",
        "عمومی",
        "یخ",
        "موضوع",
        "دایره",
        "جفت",
        "تقسیم",
        "هجاز",
        "نمد",
        "بزرگ",
        "توپ",
        "هنوز",
        "موج",
        "قلب",
        "ساعت",
        "حاضر",
        "سنگین",
        "رقص",
        "موتور",
        "موقعیت",
        "دست",
        "گسترده",
        "بادبان",
        "ماده",
        "بخش",
        "جنگل",
        "نشستن",
        "مسابقه",
        "پنجره",
        "فروشگاه",
        "تابستان",
        "قطار",
        "خواب",
        "ثابت",
        "تنها",
        "پا",
        "ورزش",
        "دیوار",
        "گرفتن",
        "کوه",
        "آرزو",
        "آسمان",
        "لذت",
        "زمستان",
        "شنبه",
        "وحشی",
        "ابزار",
        "شیشه‌ای",
        "چمن",
        "گاو",
        "کار",
        "لبه",
        "علامت",
        "بازدید",
        "گذشته",
        "نرم",
        "سرگرم",
        "روشن",
        "گاز",
        "ماه",
        "میلیون",
        "تحمل",
        "پایان",
        "شاد",
        "امیدوارم",
        "گل",
        "پوشاندن",
        "رفته",
        "تجارت",
        "ملودی",
        "سفر",
        "دفتر",
        "دریافت",
        "ردیف",
        "دهان",
        "دقیق",
        "نماد",
        "مرگ",
        "کمترین",
        "مشکل",
        "فریاد",
        "جز",
        "نوشت",
        "دانه",
        "تن",
        "عضویت",
        "تمیز",
        "استراحت",
        "خانم",
        "حیاط",
        "افزایش",
        "بد",
        "ضربه",
        "نفت",
        "خون",
        "رشد",
        "در‌صد",
        "مخلوط",
        "تیم",
        "سیم",
        "هزینه",
        "قهوه‌ای",
        "لباس",
        "باغ",
        "برابر",
        "ارسال",
        "کنید",
        "سقوط",
        "مناسب",
        "جریان",
        "عادلانه",
        "بانک",
        "ذخیره",
        "کنترل",
        "اعشاری",
        "گوش",
        "دیگر",
        "کاملا",
        "شکست",
        "مورد",
        "متوسط",
        "کشتن",
        "پسر",
        "دریاچه",
        "لحظه‌ای",
        "مقیاس",
        "باصدا",
        "بهار",
        "مشاهده",
        "کودک",
        "مستقیم",
        "همخوان",
        "کشور",
        "شیر",
        "سرعت",
        "روش",
        "عضو",
        "پرداخت",
        "سن",
        "بخش",
        "لباس",
        "ابر",
        "تعجب",
        "آرام",
        "سنگ",
        "کوچک",
        "صعود",
        "سرد",
        "طراحی",
        "ضعیف",
        "زیادی",
        "تجربه",
        "پایین",
        "کلید",
        "اهن",
        "تک",
        "چوب",
        "تخت",
        "بیست",
        "پوست",
        "لبخند",
        "چینی",
        "سوراخ",
        "کودک",
        "هشت",
        "روستای",
        "ملاقات",
        "ریشه",
        "خرید",
        "بالابردن",
        "حل",
        "فلز",
        "چه",
        "فشار",
        "هفت",
        "بند",
        "سوم",
        "باید",
        "مو",
        "توصیف",
        "آشپز",
        "طبقه",
        "یا",
        "نتیجه",
        "رایت",
        "تپه",
        "امن",
        "گربه",
        "قرن",
        "در‌نظر",
        "نوع",
        "قانون",
        "بیت",
        "ساحل",
        "کپی",
        "عبارت",
        "خاموش",
        "بلند",
        "شن",
        "خاک",
        "رول",
        "انگشت",
        "صنعت",
        "ارزش",
        "مبارزه",
        "دروغ",
        "تحریک",
        "طبیعی",
        "نظر",
        "احساس",
        "سرمایه",
        "نه",
        "صندلی",
        "خطر",
        "میوه",
        "غنی",
        "ضخامت",
        "سرباز",
        "روند",
        "کار",
        "عمل",
        "جداگانه",
        "دشوار",
        "دکتر",
        "لطفا",
        "محافظت",
        "ظهر",
        "محصول",
        "مدرن",
        "عنصر",
        "ضربه",
        "گوشه",
        "حزب",
        "عرضه",
        "که",
        "قرار",
        "حلقه",
        "شخصیت",
        "حشرات",
        "گرفتار",
        "دوره",
        "رادیو",
        "صحبت",
        "اتم",
        "انسانی",
        "تاریخ",
        "اثر",
        "برق",
        "انتظار",
        "استخوان",
        "نرده",
        "ارائه",
        "توافق",
        "بنابراین",
        "ملایم",
        "زن",
        "کاپیتان",
        "لازم",
        "تیز",
        "بال",
        "ایجاد",
        "همسایه",
        "شستشو",
        "خفاش",
        "نه",
        "جمعیت",
        "ذرت",
        "مقایسه",
        "شعر",
        "رشته",
        "زنگ",
        "گوشت",
        "مالیدن",
        "لوله",
        "معروف",
        "دلار",
        "جریان",
        "ترس",
        "نظر",
        "نازک",
        "مثلث",
        "سیاره",
        "عجله‌ای",
        "رئیس",
        "مستعمره",
        "ساعت",
        "معدن",
        "کراوات",
        "اصلی",
        "تازه",
        "جستجو",
        "ارسال",
        "زرد",
        "اسلحه",
        "اجازه",
        "چاپ",
        "مرده",
        "نقطه",
        "بیابان",
        "جریان",
        "آسانسور",
        "افزایش",
        "رسیدن",
        "کارشناس",
        "آهنگ",
        "ساحل",
        "بخش",
        "ورق",
        "ماده",
        "اتصال",
        "پست",
        "وتر",
        "چربی",
        "خوشحالم",
        "اصلی",
        "سهم",
        "ایستگاه",
        "پدر",
        "نان",
        "شارژ",
        "مناسب",
        "بار",
        "پیشنهاد",
        "بخش",
        "برده",
        "اردک",
        "فوری",
        "بازار",
        "درجه",
        "جمعیت",
        "جوجه",
        "عزیز",
        "دشمن",
        "پاسخ",
        "نوشابه",
        "پشتیبانی",
        "سخنرانی",
        "طبیعت",
        "دامنه",
        "بخار",
        "حرکت",
        "راه",
        "مایع",
        "دندانها",
        "پوسته",
        "گردن",
        "اکسیژن",
        "قند",
        "مرگ",
        "خوب",
        "مهارت",
        "زنان",
        "فصل",
        "مغناطیس",
        "نقره‌ای",
        "تشکر",
        "شاخه",
        "مسابقه",
        "پسوند",
        "ویژه",
        "انجیر",
        "ترس",
        "بزرگ",
        "خواهر",
        "فولاد",
        "بحث",
        "مشابه",
        "راهنمایی",
        "تجربه",
        "نمره",
        "سیب",
        "خریداری",
        "رهبری",
        "زمین",
        "کت",
        "جرم",
        "کارت",
        "گروه",
        "طناب",
        "لغزش",
        "برنده",
        "رویا",
        "شب",
        "شرایط",
        "خوراک",
        "ابزار",
        "کل",
        "اساسی",
        "بوی",
        "دره",
        "دو",
        "صندلی",
        "ادامه",
        "بلوک",
        "نمودار",
        "کلاه",
        "فروش",
        "موفقیت",
        "شرکت",
        "تفریق",
        "رویداد",
        "خاص",
        "معامله",
        "شنا",
        "مدت",
        "همسر",
        "کفش",
        "شانه",
        "گسترش",
        "ترتیب",
        "اردوگاه",
        "اختراع",
        "پنبه",
        "متولد",
        "تعیین",
        "کوارت",
        "نه",
        "کامیون",
        "سطح",
        "شانس",
        "فروشگاه",
        "کشش",
        "پرتاب",
        "درخشش",
        "خاصیت",
        "ستون",
        "مولکول",
        "اشتباه",
        "خاکستری",
        "تکرار",
        "نیاز",
        "پهن",
        "آماده",
        "نمک",
        "بینی",
        "جمع",
        "خشم",
        "ادعا",
        "قاره",
    )

    parts_of_speech: Dict[str, tuple] = {}



from collections import OrderedDict

from faker.utils.decorators import slugify

from .. import Provider as InternetProvider


class Provider(InternetProvider):
    user_name_formats = (
        "{{last_romanized_name}}.{{first_romanized_name}}",
        "{{first_romanized_name}}.{{last_romanized_name}}",
        "{{first_romanized_name}}##",
        "?{{last_romanized_name}}",
    )

    tlds = OrderedDict(
        (
            ("cn", 0.8),
            ("net", 0.1),
            ("com", 0.05),
            ("org", 0.05),
        )
    )

    second_level_domains = (
        "ac",
        "com",
        "edu",
        "gov",
        "mil",
        "net",
        "org",
        "ah",
        "bj",
        "cq",
        "fj",
        "gd",
        "gs",
        "gz",
        "gx",
        "ha",
        "hb",
        "he",
        "hi",
        "hk",
        "hl",
        "hn",
        "jl",
        "js",
        "jx",
        "ln",
        "mo",
        "nm",
        "nx",
        "qh",
        "sc",
        "sd",
        "sh",
        "sn",
        "sx",
        "tj",
        "xj",
        "xz",
        "yn",
        "zj",
    )

    domain_formats = (
        "##",
        "??",
        "{{first_romanized_name}}",
        "{{last_romanized_name}}",
        "{{first_romanized_name}}{{last_romanized_name}}",
        "{{last_romanized_name}}{{last_romanized_name}}",
        "{{first_romanized_name}}{{first_romanized_name}}",
    )

    @slugify
    def domain_word(self) -> str:
        pattern: str = self.random_element(self.domain_formats)
        if "#" in pattern or "?" in pattern:
            return self.bothify(pattern)
        else:
            return self.generator.parse(pattern)

    def domain_name(self, levels: int = 1) -> str:
        if levels < 1:
            raise ValueError("levels must be greater than or equal to 1")
        if levels == 1:
            domain_word = self.domain_word()
            # Avoids he.cn as seen in issue #687
            while domain_word in self.second_level_domains:
                domain_word = self.domain_word()
            return domain_word + "." + self.tld()
        elif levels == 2:
            my_tld = self.tld()
            if my_tld == "cn":
                my_second_level: str = self.random_element(self.second_level_domains)
            else:
                my_second_level = self.domain_word()
            return self.domain_word() + "." + my_second_level + "." + my_tld
        else:
            return self.domain_word() + "." + self.domain_name(levels - 1)



from typing import Tuple

from .. import Provider as BaseProvider


class Provider(BaseProvider):
    # Source:
    # https://en.wikipedia.org/wiki/National_Insurance_number
    # UK National Insurance numbers (NINO) follow a specific format
    # To avoid generating real NINOs, the prefix and suffix letters
    # remain static using values reserved by HMRC (never to be used).
    # Example format: "QR 12 34 56 C" or "QR123456C" - only alphanumeric
    # and whitespace characters are permitted. Whitespace is for readability
    # only and is generally included as per the above examples, but a
    # few 'styles' have been included below for the sake of realism.

    nino_formats: Tuple[str, ...] = (
        "ZZ ## ## ## T",
        "ZZ######T",
        "ZZ ###### T",
    )

    def ssn(self) -> str:
        pattern: str = self.random_element(self.nino_formats)
        return self.numerify(self.generator.parse(pattern))

    vat_id_formats: Tuple[str, ...] = (
        "GB### #### ##",
        "GB### #### ## ###",
        "GBGD###",
        "GBHA###",
    )

    def vat_id(self) -> str:
        """
        http://ec.europa.eu/taxation_customs/vies/faq.html#item_11
        :return: A random British VAT ID
        """
        return self.bothify(self.random_element(self.vat_id_formats))



from .. import Provider as BaseProvider


class Provider(BaseProvider):
    """
    Source: https://www.turkcebilgi.com/meslekler_listesi
    """

    jobs = [
        "Acentacı",
        "Acil durum yönetmeni",
        "Adli tabip",
        "Agronomist",
        "Ağ yöneticisi",
        "Aşçı",
        "Aşçıbaşı",
        "Ahşap tekne yapımcısı",
        "Aile hekimi",
        "Aktar",
        "Akortçu",
        "Aktör",
        "Aktüer",
        "Aktris",
        "Akustikçi",
        "Albay",
        "Ambalajcı",
        "Ambarcı",
        "Ambulans şoförü",
        "Amiral",
        "Anahtarcı",
        "Anestezi uzmanı",
        "Anestezi teknikeri",
        "Animatör",
        "Antika satıcısı",
        "Antropolog",
        "Apartman yöneticisi",
        "Araba satıcısı",
        "Araba yıkayıcısı",
        "Arabacı",
        "Arabulucu",
        "Araştırmacı",
        "Arıcı",
        "Arkeolog",
        "Armatör",
        "Arpist",
        "Arşivci",
        "Artist",
        "Asansörcü",
        "Asistan",
        "Asker",
        "Astrofizikçi",
        "Astrolog",
        "Astronom",
        "Astronot",
        "Astsubay",
        "Atlet",
        "Av bekçisi",
        "Avcı",
        "Avizeci",
        "Avukat",
        "Ayakçı (otogar, lokanta)",
        "Ayakkabı boyacısı",
        "Ayakkabı tamircisi",
        "Ayakkabıcı",
        "Ayı oynatıcısı",
        "Araba tamircisi",
        "Bacacı",
        "Badanacı",
        "Baharatçı",
        "Bahçe bitkileri uzmanı",
        "Bahçıvan",
        "Bakan",
        "Bakıcı",
        "Bakırcı",
        "Bakkal",
        "Bakteriyolog",
        "Balıkçı",
        "Balerin",
        "Balon pilotu",
        "Bankacı",
        "Banker",
        "Barmen",
        "Barmeyd",
        "Basketbolcu",
        "Başbakan",
        "Başçavuş",
        "Başdümenci",
        "Başhemşire",
        "Başkan",
        "Başkomiser",
        "Başpiskopos",
        "Başrahip",
        "Belediye başkanı",
        "Belediye meclisi üyesi",
        "Benzinci",
        "Berber",
        "Besteci",
        "Biletçi",
        "Bilgisayar mühendisi",
        "Bilgisayar programcısı",
        "Bilgisayar tamircisi",
        "Bilim insanı",
        "Bilirkişi",
        "Binicilik",
        "Biracı",
        "Bisikletçi",
        "Biyografi yazarı",
        "Biyolog",
        "Biyomedikal Mühendisi",
        "Bobinajcı",
        "Bombacı",
        "Bomba imhacı",
        "Borsacı",
        "Borucu",
        "Botanikçi",
        "Boyacı",
        "Bozacı",
        "Böcekbilimci",
        "Börekçi",
        "Bulaşıkçı",
        "Buldozer operatörü",
        "Bütçe uzmanı",
        "Büyükelçi",
        "Besicilik",
        "Bilgi İşlemci",
        "Camcı",
        "Cerrah",
        "Celep",
        "Cellat",
        "Cost Control",
        "Cillopçu",
        "Cumhurbaşkanı",
        "Çamaşırcı",
        "Çantacı",
        "Çarkçı",
        "Çatıcı",
        "Çaycı",
        "Çevirmen",
        "Çevrebilimci",
        "Çevre mühendisi",
        "Çeyizci",
        "Çıkıkçı",
        "Çıkrıkçı",
        "Çiçekçi",
        "Çiftçi",
        "Çiftlik işletici",
        "Çikolatacı",
        "Çilingir",
        "Çinici",
        "Çitçi",
        "Çoban",
        "Çocuk doktoru",
        "Çorapçı",
        "Çöp işçisi",
        "Çöpçü",
        "Çırak",
        "Çevik Kuvvet",
        "Dadı",
        "Daktilograf",
        "Dalgıç",
        "Damıtıcı",
        "Danışman",
        "Dansöz",
        "Davulcu",
        "Debbağ",
        "Dedektif",
        "Değirmen işçisi",
        "Değirmenci",
        "Demirci",
        "Demiryolu işçisi",
        "Denetçi",
        "Denetleyici",
        "Denizci",
        "Depocu",
        "Derici",
        "Desinatör",
        "Devlet memuru",
        "Dilci",
        "Dilenci",
        "Diplomat",
        "Diş hekimi",
        "Diyetisyen",
        "Dizgici",
        "Doğalgazcı",
        "Doğramacı",
        "Doğum uzmanı",
        "Dok işçisi",
        "Dokumacı",
        "Doktor",
        "Dondurmacı",
        "Dökümcü",
        "Döşemeci",
        "Dövizci",
        "Dublajcı",
        "Duvarcı",
        "Dümenci",
        "Diş teknisyeni",
        "Ebe",
        "Eczacı",
        "Eczacı kalfası",
        "Editör",
        "Eğitimci",
        "Eğitmen",
        "Ekonomist",
        "Elektrik mühendisi",
        "Elektronik mühendisi",
        "Elektrik-Elektronik mühendisi",
        "Elektronik ve Haberleşme mühendisi",
        "Elektrikçi",
        "Eleştirmen",
        "Embriyolog",
        "Emlakçı",
        "Emniyet amiri",
        "Emniyet genel müdürü",
        "Endüstri mühendisi",
        "Endüstri sistemleri mühendisi",
        "Enstrüman imalatçısı",
        "Ergonomist",
        "Eskici",
        "Esnaf",
        "Estetisyen",
        "Etolojist",
        "Etimolog",
        "Etnolog",
        "Ev hanımı",
        "Fabrika işçisi",
        "Fahişe",
        "Falcı",
        "Fermantasyon işçisi",
        "Fıçıcı",
        "Fırıncı",
        "Figüran",
        "Film yapımcısı",
        "Film yönetmeni",
        "Filozof",
        "Finansör",
        "Fizikçi",
        "Fizyonomist",
        "Fizyoterapist",
        "Acil tıp teknisyeni",
        "Fon yöneticisi",
        "Forklift operatörü",
        "Fotoğrafçı",
        "Futbolcu",
        "Gardiyan",
        "Galerici",
        "Garson",
        "Gazete dağıtıcısı",
        "Gazete satıcısı",
        "Gazeteci",
        "Gelir uzmanı",
        "Gelir uzman yardımcısı",
        "Gemici",
        "General",
        "Genetik mühendisi",
        "Geyşa",
        "Gezgin",
        "Gezici vaiz",
        "Gıda mühendisi",
        "Gitarist",
        "Gondolcu",
        "Gökbilimci",
        "Göz doktoru",
        "Gözetmen",
        "Gözlükçü",
        "Grafiker",
        "Gramer uzmanı",
        "Greyder operatörü",
        "Guru",
        "Güfteci",
        "Gümrük memuru",
        "Gümrük müşaviri",
        "Gümrük müşavir yardımcısı",
        "Gümrük uzmanı",
        "Gündelikçi",
        "Güzellik uzmanı",
        "Haberci",
        "Haddeci",
        "Haham",
        "Hakem",
        "Halıcı",
        "Halkbilimci",
        "Hamal",
        "Hamamcı",
        "Hamurkâr",
        "Hareket memuru",
        "Haritacı",
        "Harita mühendisi",
        "Hastabakıcı",
        "Hattat",
        "Hava trafikçisi",
        "Havacı",
        "Haydut",
        "Hayvan bakıcısı",
        "Hayvan terbiyecisi",
        "Hemşire",
        "Hesap uzmanı",
        "Heykeltıraş",
        "Hırdavatçı",
        "Hırsız",
        "Hidrolikçi",
        "Hizmetçi",
        "Hokkabaz",
        "Host",
        "Hostes",
        "Hukukçu",
        "Hurdacı",
        "İcra memuru",
        "İç mimar",
        "İğneci",
        "İhracatçı",
        "İktisatçı",
        "İlahiyatçı",
        "İllüzyonist",
        "İmam",
        "İnsan kaynakları uzmanı",
        "İnşaat mühendisi",
        "İnşaatçı",
        "İpçi",
        "İplikçi",
        "İstatistikçi",
        "İstihkâmcı",
        "İşaretçi",
        "İşçi",
        "İşletmeci",
        "İşletme mühendisi",
        "İşportacı",
        "İş ve Uğraşı Terapisti",
        "İtfaiyeci",
        "İthalatçı",
        "Jeofizik mühendisi",
        "Jeoloji mühendisi",
        "Jeolog",
        "Jeomorfolog",
        "Jinekolog",
        "Jimnastikçi",
        "Jokey",
        "Kabin görevlisi",
        "Kabuk soyucusu",
        "Kadın berberi",
        "Kadın terzisi",
        "Kâğıtçı",
        "Kahveci",
        "Kâhya",
        "Kalaycı",
        "Kalıpçı",
        "Kaloriferci",
        "Kamarot",
        "Kameraman",
        "Kamyoncu",
        "Kapı satıcısı",
        "Kapıcı",
        "Kaplamacı",
        "Kaportacı",
        "Kaptan",
        "Kardinal",
        "Kardiyolog",
        "Karikatürist",
        "Karoserci",
        "Karpuzcu",
        "Kasap",
        "Kasiyer",
        "Kat görevlisi",
        "Kâtip",
        "Kayıkçı",
        "Kaymakam",
        "Kaynakçı",
        "Kazıcı",
        "Kebapçı",
        "Kemancı",
        "Kesimci",
        "Keskin Nişancı",
        "Kırtasiyeci",
        "Kimyager",
        "Kimya mühendisi",
        "Kitapçı",
        "Klarnetçi",
        "Koleksiyoncu",
        "Komedyen",
        "Komisyoncu",
        "Komiser",
        "Konserveci",
        "Konsolos",
        "Konsomatris",
        "Kontrolör",
        "Konveyör operatörü",
        "Kopyalayıcı",
        "Koreograf",
        "Korgeneral",
        "Koramiral",
        "Korsan",
        "Koruma görevlisi",
        "Komiser",
        "Komiser yardımcısı",
        "Kozmolog",
        "Köfteci",
        "Kömürcü",
        "Köpek eğiticisi",
        "Köşe yazarı",
        "Kuaför",
        "Kuşçu",
        "Kumarbaz",
        "Kumaşçı",
        "Kumcu",
        "Kuru temizlemeci",
        "Kuruyemişçi",
        "Kurye",
        "Kuşbilimci",
        "Kuyumcu",
        "Kürkçü",
        "Kütüphaneci",
        "Krupiye",
        "Laborant",
        "Laboratuvar işçisi",
        "Lahmacuncu",
        "Lehimci",
        "Levazımcı",
        "Lobici",
        "Lokantacı",
        "Lokomotifçi",
        "Lostromo",
        "Lostracı",
        "Lokman",
        "Madenci",
        "Makasçı",
        "Makastar",
        "Maketçi",
        "Makinist",
        "Makine mühendisi",
        "Makine zabiti",
        "Makyajcı",
        "Mali hizmetler uzmanı",
        "Manastır baş rahibesi",
        "Manav",
        "Manifaturacı",
        "Manikürcü",
        "Manken",
        "Marangoz",
        "Masör",
        "Masöz",
        "Matador",
        "Matbaacı",
        "Matematikçi",
        "Matkapçı",
        "Medya Planlama Uzmanı",
        "Memur",
        "Menajer",
        "Mermerci",
        "Metalurji mühendisi",
        "Meteoroloji uzmanı",
        "Metin yazarı",
        "Mevsimlik işçi",
        "Meydancı",
        "Meyhaneci",
        "Mezarcı",
        "Midyeci",
        "Mikrobiyolog",
        "Milletvekili",
        "Mimar",
        "Misyoner",
        "Mobilyacı",
        "Modacı",
        "Model",
        "Modelci",
        "Modelist",
        "Montajcı",
        "Montör",
        "Motor tamircisi",
        "Motorcu",
        "Muhabbet tellalı",
        "Muhabir",
        "Muhafız",
        "Muhasebeci",
        "Muhtar",
        "Mumyalayıcı",
        "Muzcu",
        "Mübaşir",
        "Müdür",
        "Müezzin",
        "Müfettiş",
        "Müşavir",
        "Mühendis",
        "Müneccim",
        "Mürebbiye",
        "Müsteşar",
        "Müteahhit",
        "Mütercim",
        "Müze müdürü",
        "Müzik yönetmeni",
        "Müzisyen",
        "Nalıncı",
        "Nakışçı",
        "Nakliyeci",
        "Nalbant",
        "Nalbur",
        "Noter",
        "Obuacı",
        "Ocakçı",
        "Odacı",
        "Oduncu",
        "Okçu",
        "Okul müdürü",
        "Okutman",
        "Operatör",
        "Opera sanatçısı",
        "Orgcu",
        "Orgeneral",
        "Orman mühendisi",
        "Ornitolog",
        "Otelci",
        "Oto elektrikçisi",
        "Oto lastik tamircisi",
        "Oto tamircisi",
        "Oto yedek parçacı",
        "Overlokçu",
        "Oymacı",
        "Oyuncu",
        "Oyun hostesi",
        "Oyun yazarı",
        "Oyuncakçı",
        "Öğretmen",
        "Öğretim elemanı",
        "Öğretim görevlisi",
        "Öğretim üyesi",
        "Örmeci",
        "Ön muhasebeci",
        "Ön muhasebe sorumlusu",
        "Ön muhasebe yardımcı elemanı",
        "Ön büro elemanı",
        "Özel şoför",
        "Paketleyici",
        "Palyaço",
        "Pandomimci",
        "Pansiyoncu",
        "Pansumancı",
        "Papa",
        "Papaz",
        "Paralı asker",
        "Park bekçisi",
        "Pastörizör",
        "Patolog",
        "Peçeteci",
        "Pencereci",
        "Perukçu",
        "Peyzaj mimarı",
        "Peyzaj teknikeri",
        "Pideci",
        "Pilavcı",
        "Pilot",
        "Piskopos",
        "Piyade",
        "Piyango satıcısı",
        "Piyanist",
        "Polis memuru",
        "Polis şefi",
        "Polisajcı",
        "Pompacı",
        "Postacı",
        "Profesör",
        "Proktolog",
        "Protokol görevlisi",
        "Psikiyatr",
        "Psikolog",
        "Psikolojik danışmanlık ve rehberlik",
        "Paramedik",
        "Radyolog",
        "Redaktör",
        "Rehber",
        "Rejisör",
        "Reklamcı",
        "Rektör",
        "Rektör yardımcısı",
        "Remayözcü",
        "Ressam",
        "Resepsiyon memuru",
        "Rot balansçı",
        "Radyoloji teknisyeni/teknikeri",
        "Saat tamircisi",
        "Saatçi",
        "Sağlık teknisyeni",
        "Sahil koruma",
        "Saksofoncu",
        "Salepçi",
        "Sanat yönetmeni",
        "Sanayici",
        "Sansürcü",
        "Santral memuru",
        "Saraç",
        "Sarraf",
        "Satış elemanı",
        "Savcı",
        "Saz şairi",
        "Sekreter",
        "Senarist",
        "Sepetçi",
        "Serbest muhasebeci mali müşavir",
        "Ses teknisyeni",
        "Seyis",
        "Sınırlı baş makinist",
        "Sicil memuru",
        "Sigortacı",
        "Sihirbaz",
        "Silahçı",
        "Silindir operatörü",
        "Simitçi",
        "Simyacı",
        "Sistem mühendisi",
        "Sistem yöneticisi",
        "Siyasetçi",
        "Soğuk demirci",
        "Sokak çalgıcısı",
        "Sokak satıcısı",
        "Son ütücü",
        "Sorgu hâkimi",
        "Sosyal hizmet uzmanı",
        "Sosyolog",
        "Spiker",
        "Stenograf",
        "Stilist",
        "Striptizci",
        "Su tesisatçısı",
        "Subay",
        "Sucu",
        "Suflör",
        "Sulh hâkimi",
        "Sunucu",
        "Susuz araç yıkama",
        "Sünnetçi",
        "Sürveyan",
        "Sütanne",
        "Sütçü",
        "Şahinci",
        "Şair",
        "Şapel papazı",
        "Şapkacı",
        "Şarap üreticisi",
        "Şarkıcı",
        "Şarkı sözü yazarı",
        "Şarküter",
        "Şekerci",
        "Şemsiyeci",
        "Şifre çözümleyici",
        "Şimşirci",
        "Şoför",
        "Tabakçı",
        "Tabelacı",
        "Tahsildar",
        "Taksici",
        "Tarım işçisi",
        "Tarihçi",
        "Tasarımcı",
        "Taşçı",
        "Taşlayıcı",
        "Tatlıcı",
        "Tavukçu",
        "Tayfa",
        "Tefeci",
        "Teğmen",
        "Tekniker",
        "Teknisyen",
        "Teknoloji uzmani",
        "Telefon operatörü",
        "Telekız",
        "Televizyon tamircisi",
        "Tellal",
        "Temizlikçi",
        "Temsilci",
        "Terapist",
        "Tercüman",
        "Terzi",
        "Tesgahtar",
        "Tesisatçı",
        "Tesviyeci",
        "Test mühendisi",
        "Test pilotu",
        "Teşrifatçı",
        "Tiyatro yönetmeni",
        "Tombalacı",
        "Topçu",
        "Tornacı",
        "Turizmci",
        "Tuğgeneral",
        "Tuhafiyeci",
        "Turşucu",
        "Tuzcu",
        "Tümamiral",
        "Tümgeneral",
        "Uçuş teknisyeni",
        "Ulaşım sorumlusu",
        "Ustabaşı",
        "Uydu antenci",
        "Uzay mühendisi",
        "Uzay bilimcisi",
        "Uzman Jandarma",
        "Uzman Çavuş",
        "Üretici",
        "Ürolog",
        "Ütücü",
        "Vaiz",
        "Vali",
        "Vergi denetmeni",
        "Vergi müfettişi",
        "Vergi tahakkuk memuru",
        "Veritabanı yöneticisi",
        "Veri hazırlama ve kontrol işletmeni",
        "Vestiyerci",
        "Veteriner hekim",
        "Veteriner sağlık teknikeri",
        "Veteriner sağlık teknisyeni",
        "Veznedar",
        "Video editörü",
        "Vinç operatörü",
        "Vitrinci",
        "Viyolonselci",
        "Yarbay",
        "Yardımcı hakem",
        "Yardımcı hizmetli",
        "Yardımcı pilot",
        "Yargıç",
        "Yatırım uzmanı",
        "Yayıncı",
        "Yazar",
        "Yazı işleri müdürü",
        "Yazılım mühendisi",
        "Yelkenci",
        "Yeminli mali müşavir",
        "Yeminli tercüman",
        "Yer gösterici",
        "Yer teknisyeni",
        "Yerölçmeci",
        "Yoğurtçu",
        "Yol bekçisi",
        "Yorgancı",
        "Yorumcu",
        "Yönetici",
        "Yüzücü",
        "Yönetmen",
    ]
